USCFC Vaccine-Reported | US Court of Federal Claims

Skip to main content
Site map

# USCFC Vaccine-Reported

U.S. Court of Federal Claims Opinions
Updated: 6 hours 33 min ago

General Jurisdiction (Reported) | General Jurisdiction (Unreported) | Vaccine (Reported) | Vaccine (Unreported) | Search for:

### 1:11-vv-00118 • WIRT v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 05/09/2014
PUBLIC DECISION (Originally filed: 04/18/2014) regarding DECISION of Special Master Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Vaccine Act Entitlement; Causation-in-fact; Gardasil Vaccination; Rheumatoid Arthritis; Denial.

### 1:12-vv-00750 • KONAR v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/30/2014
PUBLIC DECISION (Originally filed: 03/25/2014) regarding DECISION of Special Master Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Petitioner's Motion for Dismissal Decision Dismissing the Petition; Insufficient Proof of Causation

### 1:08-vv-00818 • COOMBS et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/29/2014
PUBLIC DECISION (Originally filed: 04/08/2014) regarding DECISION of Special Master Signed by Special Master George L. Hastings.

Keywords: re: Vaccine Act Entitlement; Causation-in-fact; MMR-Varivax/Autism Spectrum Disorder.

### 1:99-vv-00578-LB • D'ANGIOLINI v. HHS

Filed 04/28/2014
PUBLIC DECISION (Originally filed: 03/27/2014) regarding DECISION of Special Master. Signed by Special Master Christian J. Moran.

Keywords: re: Public Decision hepatitis B vaccine; yeast allergy; chronic fatigue syndrome (CFS); systemic lupus erythematosus("SLE"); autoimmune syndrome induced by adjuvants (ASIA).

### 1:09-vv-00039 • CRUTCHFIELD v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/28/2014
PUBLIC DECISION (Originally filed: 04/07/2014) regarding DECISION of Special Master Signed by Special Master George L. Hastings.

Keywords: re: Vaccine Act Entitlement; Causation-in-fact; MMR vaccine;Diabetes Type I

### 1:13-vv-00280 • GRIFFIN v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/25/2014
PUBLIC DECISION (Originally filed: 04/04/2014) regarding DECISION of Special Master Signed by Special Master Laura D Millman.

Keywords: re: Public Decision: Dismissal decision; motion for summary judgment; flu vaccine; GBS; federal government contractor; not a federal employee

### 1:12-vv-00757 • MCCLENAGHAN v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/25/2014
PUBLIC DECISION (Originally filed: 04/02/2014) regarding DECISION of Special Master - Fees Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Attorneys' fees and costs; Reasonable Amount Requested to which Respondent Does Not Object

### 1:08-vv-00185 • HOLMES v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/24/2014
JUDGE VACCINE REPORTED OPINION re: Order on Motion for Review, Judge Vaccine Reported Opinion Signed by Judge Victor J. Wolski.

Keywords: re: Judge Vaccine Reported Opinion Keywords: re: [88] Judge Vaccine Reported Opinion Vaccine Act motion for review; off-table case; tetanus and diphtheria vaccination; seizure disorder; use of statistical factors; treating physicians opinions; expert witness credibility; causation-in-fact not established.

### 1:13-vv-00098 • DAHL v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/23/2014
PUBLIC ORDER/RULING (Originally filed: 04/02/2014) regarding Order Denying Motion to Exclude Expert Testimony. Signed by Special Master Christian J. Moran.

Keywords: re: Public Order/Ruling Motion to exclude expert witness

### 1:09-vv-00176 • CORTEZ et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/22/2014
PUBLIC DECISION (Originally filed: 3/26/2014) regarding DECISION of Special Master - Fees (Signed by Special Master Brian H. Corcoran.)

Keywords: Attorneys Fees; reasonable basis; recovery of fees by unsuccessfulpetitioners; proof of vaccination.

### 1:13-vv-00544 • KEGLER v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/21/2014
PUBLIC DECISION (Originally filed: 03/28/2014) regarding DECISION of Special Master - Fees Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Vaccine Act Attorneys' Fees; Reasonable Basis for a Claim.

### 1:10-vv-00566 • DIMATTEO et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/18/2014
PUBLIC DECISION (Originally filed: 03/27/2014) regarding DECISION of Special Master - Interim Attorney's Fees Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Interim Fees and Costs; Excessive Fees and Costs; Attorneys' Hourly Rates; Expert Hourly Rates; Vague or Excessive Time Entries

### 1:02-vv-01437 • TURNER, et al v. HHS

Filed 04/16/2014
PUBLIC DECISION (Originally filed: 03/26/2014) regarding DECISION of Special Master - Fees Signed by Special Master George L. Hastings.

Keywords: re: Attorneys' Fees and Costs to Former Counsel; Payment Directly to Counsel.

### 1:02-vv-00095 • FUESEL, et al v. HHS

Filed 04/09/2014
PUBLIC DECISION (Originally filed: 3/19/2014) regarding DECISION of Special Master Signed by Special Master George L. Hastings.

Keywords: re: Vaccine Act Denial of Interim Costs; Expert Costs; Reasonable Basis; Reasonable Costs

### 1:13-vv-00219 • SCANLON v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 04/01/2014
PUBLIC DECISION (Originally filed: 03/10/2014) regarding DECISION of Special Master - Fees Signed by Special Master Lisa Hamilton-Fieldman.

Keywords: re: Vaccine Act Attorneys' Fees; Reasonable Basis for a Claim.

### 1:10-vv-00261 • TOMPKINS v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 03/27/2014
JUDGE VACCINE REPORTED OPINION re: Judgment. Signed by Judge Edward J. Damich. (lp1) Copy to parties.

Keywords: Vaccine Act, 42 U.S.C. §§ 300aa-1 et seq; Review of Special Masters Decision; Off-Table Injury; Guillain-Barr Syndrome

### 1:08-vv-00570 • MATHIS et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 03/24/2014
PUBLIC DECISION (Originally filed: 1/18/13) regarding DECISION of Special Master Signed by Special Master George L. Hastings.

Keywords: re: DECISION of Special Master Autism; Statute of Limitations; Untimely Filed.

### 1:10-vv-00489 • FLORES et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 03/21/2014
JUDGE VACCINE REPORTED OPINION re: DECISION of Special Master. Signed by Judge Margaret M. Sweeney. (kb1)

Keywords: Vaccine Act; Motion for Review; HPV Vaccine; Spinal Cord Stroke; Althen; Causation-in-Fact; Burden of Proof; Genetic Susceptibility; Medical Literature; Unknown Etiology; Logical Sequence of Cause and Effect

### 1:11-vv-00654 • RAYMO et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 03/19/2014
PUBLIC ORDER/RULING (Originally filed: 02/24/2014) regarding Ruling on Entitlement Signed by Chief Special Master Denise Kathryn Vowell.

Keywords: re: Public Order/Ruling Tetanus Vaccine; Transverse Myelitis; TM; Autoimmune; Acute Transverse Myelitis; ATM; Disqualification of Experts; Factual Dispute Regarding Onset; Entitlement to Compensation

### 1:10-vv-00615 • DAVIS et al v. SECRETARY OF HEALTH AND HUMAN SERVICES

Filed 03/10/2014
PUBLIC DECISION Signed by Special Master Nora Beth Dorsey.

Keywords: re: Public Decision Entitlement; Decision without a hearing; Ruling on the record; Pediarix; Prevnar; PedvaxHIB; RotaTeq; Encephalopathy; Seizures; Congenital disorder of glycosylation; Mutation of PIGT gene.

## Pages

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »